@@ -332,7 +332,7 @@ impl Process {
         if refresh_kind.disk_usage() {
             update_disk_usage(self);
         }
-        self.run_time = now - self.start_time();
+        self.run_time = now.saturating_sub(self.start_time());
         self.updated = true;
     }
 }
